@@ -8,7 +8,6 @@
 ###########################################################################
 
 import sys
-import os
 import random
 import time
 from time import strftime
@@ -22,10 +21,11 @@ from PyQt4.QtGui import *
 import ConfigParser
 import os, os.path
 
-import data
 
-from myFunctions import *
+import data #own data
+from myFunctions import * #Own functions
 
+#GUIs
 from Ui_StartWindow import *
 from Ui_CollectingWindow import *
 from Ui_LogWindow import *
@@ -89,10 +89,10 @@ def main():
 def TimerLoop():
     global CollectingWindowGraph
 
-    r=GetSensorData()
+    r=GetSensorData() #(interval: sampling*sample_smoothing*value_smoothing)
     if(r==1):
         WriteIntoLogFile()
-        ProcessData()
+        ProcessData() 
         CollectingWindowGraph.update() #show CollectingWindowGraph    
     
     CollectingWindow.UpdateScreen()
@@ -102,12 +102,24 @@ def TimerLoop():
   
   
 ###########################################################################
-# Show the collectring window (her ethe data gets visualised during the logging)
+# Show the collectring window (hera the data gets visualised during the logging)
 ###########################################################################
 def ShowCollectingWindow():
     CollectingWindow.show()
     StartWindow.hide()
-    StartMeasurement()
+    StartMeasurement(data.sampling)
+    
+    
+###########################################################################
+# Show the collectring window (hera the data gets visualised during the logging)
+###########################################################################
+def ShowCollectingWindowTest():
+    CollectingWindow.show()
+    StartWindow.hide()
+    StartMeasurement(10)
+    data.Xscale=0 #default zoom level
+    data.test=1 #hide axis lables
+    
     
   
 ###########################################################################
@@ -165,11 +177,11 @@ def ZoomOut():
 ###########################################################################
 # Starte the measurement
 ###########################################################################
-def StartMeasurement():
+def StartMeasurement(interval):
     global CollectingWindowGraph
     global app
     
-    StartLogfile()
+    StartLogfile(interval)
     
     #init value
     data.sample_index=0
@@ -180,10 +192,10 @@ def StartMeasurement():
     data.Xscale=1 #default zoom level
     CollectingWindowGraph.show()
     
-    print "Start timers..."
+    print "Start timers (Interval:", interval ,"ms)..."
     app.timer_GetData = QtCore.QTimer()
     QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
-    app.timer_GetData.start(data.sampling)
+    app.timer_GetData.start(interval)
     
     CollectingWindow.UpdateScreenStart()
     
@@ -199,6 +211,7 @@ def StopMeasurement():
     app.timer_GetData.stop()
     StopLogfile()       
     CollectingWindow.UpdateScreenStop()
+    data.test=0 # reset test mode if was active
 
 
 
@@ -267,7 +280,7 @@ def showGraph(self):
             h0=int(strftime("%H", time.localtime()))
             m0=int(strftime("%M", time.localtime()))
         # 1 minute = 1 px
-        print "Start time of graph:",  h0,  m0
+#        print "Start time of graph:",  h0,  m0
 
         
         
@@ -283,25 +296,23 @@ def showGraph(self):
         offset=minutestonexthour*decade/60
         
         #main lines + text
-        for i in range(0, 781+decade,  decade):
-            paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
-            for k in range(1, 6):
-                x=i+offset+k*decade/6-decade
-                paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
-            h=(h0+int(i/decade)+1) % 24
-            paint.drawText(i+offset-20, data.Ysize+30, str(h)+":00") 
+        if(data.test==0):
+            for i in range(0, 781+decade,  decade):
+                paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
+                for k in range(1, 6):
+                    x=i+offset+k*decade/6-decade
+                    paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
+                h=(h0+int(i/decade)+1) % 24
+                paint.drawText(i+offset-20, data.Ysize+30, str(h)+":00") 
+        else: #test mode, do not show X scale as it is wrong
+            paint.drawText(200, data.Ysize+20, "Test Mode")
 
+
+        #trigger line
         y=(data.Ysize-(data.trigger*data.Yscale))-2
         paint.drawLine(1, y-15, 781, y-15)  
 
 
-
-
-
-
-
-
-
         #draw graph
         lastmove=0
 #        print shift,  data.arrDataIndex-data.derivation,  Xscale
@@ -310,29 +321,30 @@ def showGraph(self):
         for i in range(0,  data.arrDataIndex-shift-data.derivation,  Xscale):
             k=i+shift
             
-#           #            mov=0
-#            peak=0
-#            for j in range(0, Xscale):
-#                if(data.arrData[5][i+j]==1):
-#                    mov=mov+1
-#                    x=(abs(data.arrData[3][i])+abs(data.arrData[4][i]))
-#                    if(x>peak): peak=x
-#            print data.arrData[0][i],  i,  "...",  i+j,  "=>",  mov
-
             
             
-            if(1): #one or more movement for this pixel
-                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
-                Y=peak*data.Yscale
-                #Draw movement line
-                paint.setPen(QtGui.QColor("yellow"))
-                paint.setBrush(QtGui.QColor("yellow"))
-                paint.drawLine(i/Xscale, data.Ysize-Y-1-15, i/Xscale, data.Ysize-1-15)  
-                
-                
-                #fill space between yellow movement lines
+            #when Xscale is small, we have to merge several records into 1 pixel.
+            #To not miss any movement, we use the biggest movement of the merged records:
+            peak=0
+            for j in range(0, Xscale):
+                p=abs(data.arrData[3][k])+abs(data.arrData[4][k])
+                if(p>peak): peak=p
+           
+            
+            
+            
+#            if(1): #one or more movement for this pixel
+#                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
+            Y=peak*data.Yscale
+            #Draw movement line
+            paint.setPen(QtGui.QColor("yellow"))
+            paint.setBrush(QtGui.QColor("yellow"))
+            paint.drawLine(i/Xscale, data.Ysize-Y-1-15, i/Xscale, data.Ysize-1-15)  
+            
+            
+            #fill space between yellow movement lines
 #                if(k>lastmove+1):k
-                if(peak>data.trigger):
+            if(peak>data.trigger):
 ##                    1=10 sec
 #                    if((i-lastmove)>30*Xscale): color="#009100" #green
 #                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
@@ -342,19 +354,19 @@ def showGraph(self):
 #                    elif(t>15): color="#005000" #dark green
 #                    else: color="#6D0000" #dark red 
 
-                    x0=lastmove/Xscale+1
-                    x1=i/Xscale-1
-                    if(x0<x1):
-                        t=(x1-x0)*Xscale/6          
+                x0=lastmove/Xscale+1
+                x1=i/Xscale-1
+                if(x0<x1):
+                    t=(x1-x0)*Xscale/6          
 #                        print x0,  "<=>",  x1,  t,  Xscale
-                        if(t>30): color="#009100" #green
-                        elif(t>15): color="#005000" #dark green
-                        else: color="#6D0000" #dark red                         
-                        paint.setBrush(QtGui.QColor(color))
-                        paint.setPen(QtGui.QColor(color))
-                        paint.drawRect(x0, data.Ysize-11, x1-x0, 10) 
+                    if(t>30): color="#009100" #green
+                    elif(t>15): color="#005000" #dark green
+                    else: color="#6D0000" #dark red                         
+                    paint.setBrush(QtGui.QColor(color))
+                    paint.setPen(QtGui.QColor(color))
+                    paint.drawRect(x0, data.Ysize-11, x1-x0, 10) 
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
-                    lastmove=i
+                lastmove=i
 
 
 
@@ -439,6 +451,7 @@ class frmStartWindow(QtGui.QWidget):
 
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), ShowCollectingWindow)
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), ShowLogWindow)
+        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), ShowCollectingWindowTest)
 
     def UpdateScreenStart(self):
         try:   
@@ -478,7 +491,10 @@ class frmCollectingWindow(QtGui.QWidget):
     def UpdateScreen(self):
 #            self.ui.lblXacc.setText(str(data.arrData[1][data.arrDataIndex]))
 #            self.ui.lblYacc.setText(str(data.arrData[2][data.arrDataIndex]))
+        if(data.demo==0):
             self.ui.lblSamples_Taken.setText(str(data.values_total))
+        else:
+            self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Demo Mode)")
 
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
@@ -532,6 +548,9 @@ class frmLogWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), NextLogFile)
         QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)
+        
+#        self.ui.bZoomIn.setPixmap(QtGui.QPixmap(app_path+"/zoom-in.png"))
+#        self.ui.bZoomOut.setPixmap(QtGui.QPixmap(app_path+"/zoom-out.png"))
 
 
     def UpdateScreen(self):
@@ -611,7 +630,7 @@ class frmNoteWindow(QtGui.QWidget):
 class CollectingWindowCanvas(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, CollectingWindow)    
-        self.setGeometry(9, 200, 782, data.Ysize+30)
+        self.setGeometry(9, 230, 782, data.Ysize+30)
     
     def paintEvent(self, event):
         showGraph(self)
